PhotoBrowserController class
- Mixed-in types
Constructors
Properties
- disposed → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
-
imageInfo
→ Map<
int, ImageInfo> -
final
- notificationName ↔ String?
-
getter/setter pair
- pageController → PageController?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
thumbImageInfo
→ Map<
int, ImageInfo> -
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
dispose(
) → void -
Discards any resources used by the object.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
override
-
notifyWithName(
{String? name}) → void -
pop(
) → void -
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
setState(
VoidCallback fn) → dynamic -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
of(
BuildContext context) → PhotoBrowserController?